# January 25, 2022

**Date:** January 25, 2022, at 8am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2022-01-25/8:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)**

**[YouTube link](https://youtu.be/zMBAEtEygOA)** 

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

This is a place to make short announcements (without a need for discussion). 

* Zach has a shout out! Hooray for these calls continuing into 2022!
* Tony: congrats to the team who made the first two Jupyter accessibility workshops happen in the last two weeks
* Steve: Shout out to Zach for being an early adopter of the new Jupyter governance process with jupyter-server!
* Tony: Shout out to Darian for sharing the Jupyter governance process changes with the whole community
* Tony: Great work to the Binder team for keeping Binder ready to go for the world.
* Tony: Thanks to everyone attending for keeping community calls running
* Zach: Cool demo on Twitter of MyST in a Jupyter notebook (this is later on the agenda)

## Agenda Items

* **MLflow Kernel Demo** by Jitendra Pandey (jitendra@infinstor.com). MLflow Kernel connects to an MLflow service and records all the data science activities in the Jupyter notebook as MLflow artifacts. It is open source at [infinstor/mlflow-kernel](https://github.com/infinstor/mlflow-kernel) and [Infinstor quickstart: mlflow kernel](https://www.infinstor.com/quickstart/mlflow-kernel.)
* Demonstrations of [Jupyter cache](https://jupyter-cache.readthedocs.io), [JupyterLab MyST](https://github.com/executablebooks/jupyterlab-myst) (and maybe [PR to rewrite myst-nb](https://github.com/executablebooks/MyST-NB/pull/380))

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- [rst-to-myst](https://github.com/executablebooks/rst-to-myst)

## Attendees 

|   Name   |           Institution     | GitHub Handle|
|----------|---------------------------|--------------|
| jitendra |  [InfinStor](https://www.infinstor.com/)    | InfinStor
| Frederic Collonval | QuantStack | @fcollonval | 
| Chris Sewell | EPFL/EBP | @chrisjsewell
| Sarah Gibson | 2i2c | @sgibson91
| Simon Li | University of Dundee | @manics
| Rollin Thomas | NERSC | @rcthomas 
| Zach Sailer | Apple | @Zsailer
| Adhitya Vadivel |  [InfinStor](https://www.infinstor.com/)    | @adhityav
| Gabriel Fouasnon | Quansight | @gabalafou |
| Wayne Decatur | Upstate Medical University | @fomightez
| tony fast | Quansight | @tonyfast |
| A. T. Darian | Two Sigma | @afshin |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |

Plus 6 more